@@ -152,22 +152,23 @@ def fpc_get_nodeperm(ipmicmd, number, sz):
         rsp['data'] = b'\x00' + bytes(rsp['data'])
     elif len(rsp['data']) == 6:  # New FPC format
         rsp['data'] = bytes(rsp['data'][:2]) + bytes(rsp['data'][3:])
-    perminfo = bytearray(rsp['data'])[1]
+    permdata = bytearray(rsp['data'])
+    perminfo = permdata[1]
     if sz == 6:  # FPC
-        permfail = ('\x02', '\x03')
+        permfail = (2, 3)
     else:  # SMM
-        permfail = ('\x02',)
+        permfail = (2,)
     if perminfo & 0x20:
-        if rsp['data'][4] in permfail:
+        if permdata[4] in permfail:
             states.append('Insufficient Power')
             health = pygconst.Health.Failed
-        elif rsp['data'][3:5] != '\x00\x00':
+        elif rsp['data'][3:5] != '\x00\x00' and permdata[4] not in (0, 1):
             states.append('No Power Permission')
             health = pygconst.Health.Failed
     if perminfo & 0x40:
         states.append('Node Fault')
         health = pygconst.Health.Failed
-    if rsp['data'][3:5] == '\x00\x00':
+    if rsp['data'][3:5] == '\x00\x00' or permdata[4] == 0:
         states.append('Absent')
     return (health, states)
 
@@ -568,6 +569,30 @@ class SMMClient(object):
             }
         except Exception:
             pass
+        try:
+            chassisvpd = self.ipmicmd.xraw_command(0x32, 0xb0, data=(5, 0))
+            chassisvpd = bytearray(chassisvpd['data'][2:])
+            chassisvpd = bytes(chassisvpd).strip()
+            if not isinstance(chassisvpd, str):
+                chassisvpd = chassisvpd.decode('utf8')
+            settings['chassis_model'] = {
+                'value': chassisvpd,
+                'help': ('Configure the chassis model number')
+            }
+        except Exception:
+            pass
+        try:
+            chassisvpd = self.ipmicmd.xraw_command(0x32, 0xb0, data=(5, 1))
+            chassisvpd = bytearray(chassisvpd['data'][2:])
+            chassisvpd = bytes(chassisvpd).strip()
+            if not isinstance(chassisvpd, str):
+                chassisvpd = chassisvpd.decode('utf8')
+            settings['chassis_serial'] = {
+                'value': chassisvpd,
+                'help': ('Configure the chassis serial number')
+            }
+        except Exception:
+            pass
         return settings
 
     def set_bay_cap(self, baynum, val):
@@ -589,6 +614,8 @@ class SMMClient(object):
         powercfg = [None, None]
         sendhost = None
         sendvci = None
+        newserial = None
+        newmodel = None
         for key in changeset:
             if not key:
                 raise pygexc.InvalidParameterValue('Empty key is invalid')
@@ -620,6 +647,10 @@ class SMMClient(object):
                 sendvci = stringtoboolean(
                     changeset[key]['value'],
                     'dhcp_sends_vendor_class_identifier')
+            if fnmatch.fnmatch('chassis_serial', key.lower()):
+                newserial = changeset[key]['value']
+            if fnmatch.fnmatch('chassis_model', key.lower()):
+                newmodel = changeset[key]['value']
             # Variant low 8 bits is the height in U of chassis, so double that
             #  to get maxbays
             numbays = (self.smm_variant & 0x0f) << 1
@@ -672,6 +703,14 @@ class SMMClient(object):
         if sendvci is not None:
             sendvci = 1 if sendvci else 0
             self.ipmicmd.xraw_command(0xc, 1, data=[1, 0xc6, sendvci])
+        if newserial:
+            newserial = newserial.ljust(10).encode('utf8')
+            cmdata = b'\x05\x01' + newserial
+            self.ipmicmd.xraw_command(0x32, 0xaf, data=cmdata)
+        if newmodel:
+            newmodel = newmodel.ljust(10).encode('utf8')
+            cmdata = b'\x05\x00' + newmodel
+            self.ipmicmd.xraw_command(0x32, 0xaf, data=cmdata)
 
     def set_user_priv(self, uid, priv):
         if priv.lower() == 'administrator':
